summaryrefslogtreecommitdiffstats
path: root/extensions/common/extension_messages.h
diff options
context:
space:
mode:
authorrockot <rockot@chromium.org>2015-08-14 19:57:12 -0700
committerCommit bot <commit-bot@chromium.org>2015-08-15 02:58:16 +0000
commit49e40cc11f68ffe6ede21f0c3e1db0239d456a7a (patch)
tree53a9455581d3de8b85764d259a50fb727f747aa4 /extensions/common/extension_messages.h
parent8b605f21c02e8e920dcd7b26aa9716bb8ed751ad (diff)
downloadchromium_src-49e40cc11f68ffe6ede21f0c3e1db0239d456a7a.zip
chromium_src-49e40cc11f68ffe6ede21f0c3e1db0239d456a7a.tar.gz
chromium_src-49e40cc11f68ffe6ede21f0c3e1db0239d456a7a.tar.bz2
Ensure proper ordering of app window request block/unblock
This fixes a race in app window initialization which could cause resources to be permanently blocked from loading on behalf of the renderer. BUG=520750 TBR=kalman@chromium.org for tabs TBR=nasko@chromium.org for IPC message (symbol rename only) Review URL: https://codereview.chromium.org/1294923002 Cr-Commit-Position: refs/heads/master@{#343552}
Diffstat (limited to 'extensions/common/extension_messages.h')
-rw-r--r--extensions/common/extension_messages.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/extensions/common/extension_messages.h b/extensions/common/extension_messages.h
index 8ae6d19..49aee48 100644
--- a/extensions/common/extension_messages.h
+++ b/extensions/common/extension_messages.h
@@ -730,8 +730,9 @@ IPC_MESSAGE_ROUTED0(ExtensionHostMsg_DecrementLazyKeepaliveCount)
IPC_SYNC_MESSAGE_CONTROL0_1(ExtensionHostMsg_GenerateUniqueID,
int /* unique_id */)
-// Resumes resource requests for a newly created app window.
-IPC_MESSAGE_CONTROL1(ExtensionHostMsg_ResumeRequests, int /* route_id */)
+// Notify the browser that an app window is ready and can resume resource
+// requests.
+IPC_MESSAGE_CONTROL1(ExtensionHostMsg_AppWindowReady, int /* route_id */)
// Sent by the renderer when the draggable regions are updated.
IPC_MESSAGE_ROUTED1(ExtensionHostMsg_UpdateDraggableRegions,